@@ -5,7 +5,7 @@ use strict;
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2024-01-15'; # DATE
 our $DIST = 'Acme-CPANModules-PortedFrom-NPM'; # DIST
-our $VERSION = '0.006'; # VERSION
+our $VERSION = '0.007'; # VERSION
 
 our $LIST = {
     summary => "List of modules/applications that are ported (or inspired from) NPM libraries",
@@ -52,6 +52,11 @@ _
             npm_module => 'lodash',
             tags => [],
         },
+        {
+            module => 'Hash::Util::Pick',
+            npm_module => 'lodash',
+            tags => [],
+        },
     ],
 };
 
@@ -70,7 +75,7 @@ Acme::CPANModules::PortedFrom::NPM - List of modules/applications that are porte
 
 =head1 VERSION
 
-This document describes version 0.006 of Acme::CPANModules::PortedFrom::NPM (from Perl distribution Acme-CPANModules-PortedFrom-NPM), released on 2024-01-15.
+This document describes version 0.007 of Acme::CPANModules::PortedFrom::NPM (from Perl distribution Acme-CPANModules-PortedFrom-NPM), released on 2024-01-15.
 
 =head1 DESCRIPTION
 
@@ -108,6 +113,10 @@ Author: L<MIKIHOSHI|https://metacpan.org/author/MIKIHOSHI>
 
 Author: L<ODDTUPLE|https://metacpan.org/author/ODDTUPLE>
 
+=item L<Hash::Util::Pick>
+
+Author: L<PINE|https://metacpan.org/author/PINE>
+
 =back
 
 =head1 FAQ
